==> weixin-popular-2.8.5-sources.jar: weixin/popular/bean/paymch/GethbinfoResult.java <==
package weixin.popular.bean.paymch;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "xml")
@XmlAccessorType(XmlAccessType.FIELD)
public class GethbinfoResult extends MchBase {
	
	private String mch_billno;
	private String detail_id;
	private String status;		/* 红包状态
									SENDING:发放中 
									SENT:已发放待领取 
									FAILED：发放失败 
									RECEIVED:已领取 
									RFUND_ING:退款中 
									REFUND:已退款*/
	private String send_type;	/* 发放类型
									API:通过API接口发放 
									UPLOAD:通过上传文件方式发放 
									ACTIVITY:通过活动方式发放*/
	private String hb_type;		/*红包类型	
									GROUP:裂变红包 
									NORMAL:普通红包*/
	
	private Integer total_num;
	private Integer total_amount;
	private String reason;
	private String send_time;
	private String refund_time;
	private Integer refund_amount;
	private String wishing;
	private String remark;
	private String act_name;
	private String hblist;
	private String openid;
	private Integer amount;
	private String rcv_time;

	public String getMch_billno() {
		return mch_billno;
	}

	public void setMch_billno(String mch_billno) {
		this.mch_billno = mch_billno;
	}

	public String getDetail_id() {
		return detail_id;
	}

	public void setDetail_id(String detail_id) {
		this.detail_id = detail_id;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getSend_type() {
		return send_type;
	}

	public void setSend_type(String send_type) {
		this.send_type = send_type;
	}

	public String getHb_type() {
		return hb_type;
	}

	public void setHb_type(String hb_type) {
		this.hb_type = hb_type;
	}

	public Integer getTotal_num() {
		return total_num;
	}

	public void setTotal_num(Integer total_num) {
		this.total_num = total_num;
	}

	public Integer getTotal_amount() {
		return total_amount;
	}

	public void setTotal_amount(Integer total_amount) {
		this.total_amount = total_amount;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public String getSend_time() {
		return send_time;
	}

	public void setSend_time(String send_time) {
		this.send_time = send_time;
	}

	public String getRefund_time() {
		return refund_time;
	}

	public void setRefund_time(String refund_time) {
		this.refund_time = refund_time;
	}

	public Integer getRefund_amount() {
		return refund_amount;
	}

	public void setRefund_amount(Integer refund_amount) {
		this.refund_amount = refund_amount;
	}

	public String getWishing() {
		return wishing;
	}

	public void setWishing(String wishing) {
		this.wishing = wishing;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getAct_name() {
		return act_name;
	}

	public void setAct_name(String act_name) {
		this.act_name = act_name;
	}

	public String getHblist() {
		return hblist;
	}

	public void setHblist(String hblist) {
		this.hblist = hblist;
	}

	public String getOpenid() {
		return openid;
	}

	public void setOpenid(String openid) {
		this.openid = openid;
	}

	public Integer getAmount() {
		return amount;
	}

	public void setAmount(Integer amount) {
		this.amount = amount;
	}

	public String getRcv_time() {
		return rcv_time;
	}

	public void setRcv_time(String rcv_time) {
		this.rcv_time = rcv_time;
	}
	
}

==> weixin-popular-2.8.26-sources.jar: weixin/popular/bean/paymch/GethbinfoResult.java <==
package weixin.popular.bean.paymch;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "xml")
@XmlAccessorType(XmlAccessType.FIELD)
public class GethbinfoResult extends MchBase{
	
	private String mch_billno;
	private String detail_id;
	private String status;		/* 红包状态
									SENDING:发放中 
									SENT:已发放待领取 
									FAILED：发放失败 
									RECEIVED:已领取 
									RFUND_ING:退款中 
									REFUND:已退款*/
	private String send_type;	/* 发放类型
									API:通过API接口发放 
									UPLOAD:通过上传文件方式发放 
									ACTIVITY:通过活动方式发放*/
	private String hb_type;		/*红包类型	
									GROUP:裂变红包 
									NORMAL:普通红包*/
	
	private Integer total_num;
	private Integer total_amount;
	private String reason;
	private String send_time;
	private String refund_time;
	private Integer refund_amount;
	private String wishing;
	private String remark;
	private String act_name;
	@XmlElementWrapper(name="hblist")
	@XmlElement(name="hbinfo")
	private List<Hbinfo> hblist;

	public String getMch_billno() {
		return mch_billno;
	}

	public void setMch_billno(String mch_billno) {
		this.mch_billno = mch_billno;
	}

	public String getDetail_id() {
		return detail_id;
	}

	public void setDetail_id(String detail_id) {
		this.detail_id = detail_id;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getSend_type() {
		return send_type;
	}

	public void setSend_type(String send_type) {
		this.send_type = send_type;
	}

	public String getHb_type() {
		return hb_type;
	}

	public void setHb_type(String hb_type) {
		this.hb_type = hb_type;
	}

	public Integer getTotal_num() {
		return total_num;
	}

	public void setTotal_num(Integer total_num) {
		this.total_num = total_num;
	}

	public Integer getTotal_amount() {
		return total_amount;
	}

	public void setTotal_amount(Integer total_amount) {
		this.total_amount = total_amount;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public String getSend_time() {
		return send_time;
	}

	public void setSend_time(String send_time) {
		this.send_time = send_time;
	}

	public String getRefund_time() {
		return refund_time;
	}

	public void setRefund_time(String refund_time) {
		this.refund_time = refund_time;
	}

	public Integer getRefund_amount() {
		return refund_amount;
	}

	public void setRefund_amount(Integer refund_amount) {
		this.refund_amount = refund_amount;
	}

	public String getWishing() {
		return wishing;
	}

	public void setWishing(String wishing) {
		this.wishing = wishing;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getAct_name() {
		return act_name;
	}

	public void setAct_name(String act_name) {
		this.act_name = act_name;
	}

	public List<Hbinfo> getHblist() {
		return hblist;
	}

	public void setHblist(List<Hbinfo> hblist) {
		this.hblist = hblist;
	}
	
}
